@@ -4,7 +4,7 @@
  * This file is part of pgFouine.
  * 
  * pgFouine - a PostgreSQL log analyzer
- * Copyright (c) 2005-2006 Guillaume Smet
+ * Copyright (c) 2005-2008 Guillaume Smet
  *
  * pgFouine is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,10 @@ class PostgreSQLContinuationLine extends PostgreSQLLogLine {
 		}
 		$this->PostgreSQLLogLine($text);
 	}
+	
+	function isContextual() {
+		return true;
+	}
 }
 
 ?>
\ No newline at end of file
