@@ -25,7 +25,7 @@ class SyslogPostgreSQLParser extends PostgreSQLParser {
 	var $regexpSyslogContext;
 	
 	function SyslogPostgreSQLParser($syslogString = CONFIG_SYSLOG_IDENTITY) {
-		$this->regexpSyslogContext = new RegExp('/^((?:[0-9]{4} )?[A-Z][a-z]{2} [ 0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}) .*? '.$syslogString.'\[(\d{1,7})\]: .*?\[(\d{1,20})(?:\-(\d{1,5}))?\] /');
+		$this->regexpSyslogContext = new RegExp('/^((?:[0-9]{4}\-[0-9]{2}\-[0-9]{2}T[0-9]{2}:[0-9]{2}:[0-9]{2})|(?:(?:[0-9]{4} )?[A-Z][a-z]{2} [ 0-9]{2} [0-9]{2}:[0-9]{2}:[0-9]{2}))..*? '.$syslogString.'\[(\d{1,7})\]: .*?\[(\d{1,20})(?:\-(\d{1,5}))?\] /');
 	}
 
 	function & parse($data) {
@@ -45,18 +45,7 @@ class SyslogPostgreSQLParser extends PostgreSQLParser {
 		
 		$formattedDate = $matches[1][0];
 		
-		if(preg_match('/^[0-9]{4} /', $formattedDate)) {
-			$timestamp = strtotime(preg_replace('/^([0-9]{4} )([a-z]{3}[ ]+[0-9]{1,2})/i', '\2 \1', $formattedDate));
-		} else {
-			$timestamp = strtotime(preg_replace('/(^[a-z]{3}[ ]+[0-9]{1,2})/i', '\1 '.date('Y'), $formattedDate));
-	
-			if($timestamp > time()) {
-				$timestamp = strtotime(preg_replace('/(^[a-z]{3}[ ]+[0-9]{1,2})/i', '\1 '.(date('Y')-1), $formattedDate));
-			}
-		}
-		if($timestamp < 0) {
-			$timestamp = 0;
-		}
+		$timestamp = $this->getTimestampFromFormattedDate($formattedDate);
 		
 		$connectionId = $matches[2][0];
 		$commandNumber = $matches[3][0];
@@ -74,6 +63,29 @@ class SyslogPostgreSQLParser extends PostgreSQLParser {
 		}
 		return $line;
 	}
+	
+	function getTimestampFromFormattedDate($formattedDate) {
+		$matches = array();
+		if(preg_match('/^[0-9]{4}([- ])/', $formattedDate, $matches)) {
+			if ($matches[1] == ' ') {
+				$timestamp = strtotime(preg_replace('/^([0-9]{4} )([a-z]{3}[ ]+[0-9]{1,2})/i', '\2 \1', $formattedDate));
+			} else {
+				$timestamp = strtotime($formattedDate);
+			}
+		} else {
+			$dateFormat = '/(^[a-z]{3}[ ]+[0-9]{1,2})/i';
+			
+			$timestamp = strtotime(preg_replace($dateFormat, '\1 '.date('Y'), $formattedDate));
+	
+			if($timestamp > time()) {
+				$timestamp = strtotime(preg_replace($dateFormat, '\1 '.(date('Y')-1), $formattedDate));
+			}
+		}
+		if($timestamp < 0) {
+			$timestamp = 0;
+		}
+		return $timestamp;
+	}
 }
 
 ?>
\ No newline at end of file
